@@ -5,11 +5,13 @@ Created on Thu Dec 17 17:57:33 2020
 @author: willi
 """
 
-from . import GenericMetaData
-GenericMetaData = GenericMetaData.GenericMetaData
-import numpy as np
+
 import json, codecs
 from json import encoder
+import numpy as np
+from . import GenericMetaData
+GenericMetaData = GenericMetaData.GenericMetaData
+
 
 class SSA_Soln():
     '''
@@ -37,54 +39,56 @@ class SSA_Soln():
 
 
 
-    def save(self,filename, precision = '.4f'):
+    def save(self, filename, precision='.4f'):
         ext = filename.split('.')[-1]
-        
-        if 'txt' == ext:
-            self.__save_txt(filename)
-        if 'json' == ext:
-            self.__save_json(filename,precision= precision)
-            
 
-    def load(self,filename):
+        if ext == 'txt':
+            self.__save_txt(filename)
+        if ext == 'json':
+            self.__save_json(filename, precision=precision)
+
+
+    def load(self, filename):
         ext = filename.split('.')[-1]
-        
-        if 'txt' == ext:
+
+        if ext == 'txt':
             self.__load_from_txt(filename)
-        if 'json' == ext:
+        if ext == 'json':
             self.__load_from_json(filename)
 
-    def __save_txt(self,filename):
+    def __save_txt(self, filename):
 
         if '.txt' in filename:
-            f = open(filename, 'a')
+            filehandle = open(filename, 'a')
             for key in self.__dict__.keys():
 
                 if key != 'rib_vec' and key != 'ribosome_means':
-                    f.write((key + '\r\n'))
-                    np.savetxt(f, np.atleast_2d(self.__dict__[key]), delimiter=',', fmt='%s')
-                    f.write(('\r\n'))
+                    filehandle.write((key + '\r\n'))
+                    np.savetxt(filehandle, np.atleast_2d(self.__dict__[key]),
+                               delimiter=',', fmt='%s')
+                    filehandle.write(('\r\n'))
 
         else:
             filename = filename + '.txt'
-            f = open(filename,'a')
+            filehandle = open(filename, 'a')
             for key in self.__dict__.keys():
 
                 if key != 'rib_vec' and key != 'ribosome_means':
-                    f.write((key + '\r\n'))
-                    np.savetxt(f, np.atleast_2d(self.__dict__[key]), delimiter=',', fmt='%s')
-                    f.write(('\r\n'))
-        f.close()
-        
+                    filehandle.write((key + '\r\n'))
+                    np.savetxt(filehandle, np.atleast_2d(self.__dict__[key]),
+                               delimiter=',', fmt='%s')
+                    filehandle.write(('\r\n'))
+        filehandle.close()
+
 
     def __load_from_txt(self, filename):
         if '.txt' in filename:
-            ssa_obj = np.loadtxt(filename, dtype=str,delimiter='\n')
+            ssa_obj = np.loadtxt(filename, dtype=str, delimiter='\n')
             solutions = []
-            for i in range(0,len(ssa_obj)-1):
+            for i in range(0, len(ssa_obj)-1):
                 label = ssa_obj[i]
-                
-                
+
+
                 if label in ['rib_means',
                              'rib_vec',
                              'n_traj',
@@ -105,8 +109,10 @@ class SSA_Soln():
                              'time_inhibit',
                              'evaluating_frap']:
 
-                    if label in ['start_time', 'no_rib_per_mrna', 'ke_sim', 'dwelltime','ke_true','time_inhibit']:
-                        
+                    if label in ['start_time', 'no_rib_per_mrna',
+                                 'ke_sim', 'dwelltime', 'ke_true',
+                                 'time_inhibit']:
+
                         array = np.fromstring(ssa_obj[i+1], dtype=float, sep=',')[0]
                         exec(('self.'+label+ '=array'))
                     elif label in ['n_traj']:
@@ -116,37 +122,39 @@ class SSA_Soln():
                         array = np.fromstring(ssa_obj[i+1], dtype=float, sep=',')
                         exec(('self.'+label+ '=array'))
 
-                if label in ['evaluating_inhibitor','evaluating_frap']:
-                    if 'False' in ssa_obj[i+1]:                         
+                if label in ['evaluating_inhibitor', 'evaluating_frap']:
+                    if 'False' in ssa_obj[i+1]:
                         exec(('self.'+label+ '=False'))
-                    if 'True' in ssa_obj[i+1]:                         
+                    if 'True' in ssa_obj[i+1]:
                         exec(('self.'+label+ '=True'))
 
 
-            for i in range(0,len(ssa_obj)-1):
-                label = ssa_obj[i]                    
-                    
+            for i in range(0, len(ssa_obj)-1):
+                label = ssa_obj[i]
+
                 if label == 'intensity_vec':
 
-                    tvec = self.time_vec_fixed[np.where(self.time_vec_fixed >= self.start_time)]
+                    #tvec = self.time_vec_fixed[np.where(self.time_vec_fixed >= self.start_time)]
                     i_vec = np.zeros((self.n_traj, len(self.time)))
 
                     for j in range(self.n_traj):
-                        array = np.fromstring(ssa_obj[i+j+1], dtype=float,sep=',')
+                        array = np.fromstring(ssa_obj[i+j+1],
+                                              dtype=float, sep=',')
                         i_vec[j] = array
-                        
+
                     exec(('self.'+label+ '=i_vec'))
-                     
-                if label == 'solutions':    
+
+                if label == 'solutions':
                     for j in range(self.n_traj):
-                        array = np.fromstring(ssa_obj[i+j+1], dtype=float,sep=',')
+                        array = np.fromstring(ssa_obj[i+j+1],
+                                              dtype=float, sep=',')
                         solutions.append(array)
-                        
+
                     exec(('self.'+label+ '=solutions'))
-                        
-                  
-                    
-                    
+
+
+
+
     def make_dict(self):
         ssadict = {}
         for key in self.__dict__.keys():
@@ -156,36 +164,36 @@ class SSA_Soln():
                     ssadict[key] = self.__dict__[key].tolist()
                 except:
                     ssadict[key] = self.__dict__[key]
-                
+
             if key == 'col_points':
-                col_pt = [x.tolist() for x in self.__dict__[key] ] 
-                ssadict[key] = col_pt                
-                    
-                    
-        return ssadict          
-                     
-                     
-    def __set_float_pres(self,precision='.4f'):
+                col_pt = [x.tolist() for x in self.__dict__[key]]
+                ssadict[key] = col_pt
+
+
+        return ssadict
+
+
+    def __set_float_pres(self, precision='.4f'):
         print(precision)
-        encoder.FLOAT_REPR = lambda o: format(o,precision)
-        
-    
-    def __make_float(self,float_like, precision):
+        encoder.FLOAT_REPR = lambda o: format(o, precision)
+
+
+    def __make_float(self, float_like, precision):
         return float(('%' + precision) % float_like)
-        
-    def __format_floats(self,arraylike,precision='.4f'):
-        
+
+    def __format_floats(self, arraylike, precision='.4f'):
+
         n_decimals = int(precision.split('.')[1][:-1])
         if isinstance(arraylike, np.ndarray):
-            tmp_arr = np.around( arraylike, decimals=n_decimals ) .tolist()
+            tmp_arr = np.around(arraylike, decimals=n_decimals) .tolist()
             return tmp_arr
         else:
             tmp_arr = arraylike
-            if isinstance(tmp_arr,float):
+            if isinstance(tmp_arr, float):
                 return self.__make_float(tmp_arr, precision)
-            if isinstance(tmp_arr,list):
-                return [self.__make_float(x,precision) for x in tmp_arr]
-        
+            if isinstance(tmp_arr, list):
+                return [self.__make_float(x, precision) for x in tmp_arr]
+
 
     def __save_json(self, filename, precision='.4f'):
 
@@ -193,23 +201,27 @@ class SSA_Soln():
 
             ssadict = {}
             for key in self.__dict__.keys():
-                
+
                 if key != 'col_points':
-                
+
                     if type(self.__dict__[key]) in [float, list, np.ndarray]:
-                        
-                        ssadict[key] =  self.__format_floats(self.__dict__[key], precision= precision)
+
+                        ssadict[key] = self.__format_floats(self.__dict__[key],
+                                                            precision=precision)
                     else:
                         ssadict[key] = self.__dict__[key]
-                    
+
                 if key == 'col_points':
-                    col_pt = [x.tolist() for x in self.__dict__[key] ] 
+                    col_pt = [x.tolist() for x in self.__dict__[key]]
                     ssadict[key] = col_pt
-                    
-            json.dump(ssadict, codecs.open(filename, 'w', encoding='utf-8'), separators=(',', ':'), sort_keys=True, indent=4)
+
+            json.dump(
+                ssadict, codecs.open(
+                    filename, 'w', encoding='utf-8'),
+                separators=(',', ':'), sort_keys=True, indent=4)
 
         else:
-            filename =  filename + '.json'
+            filename = filename + '.json'
 
             ssadict = {}
             for key in self.__dict__.keys():
@@ -219,22 +231,29 @@ class SSA_Soln():
                     except:
                         ssadict[key] = self.ssa_harr.__dict__[key]
 
-            json.dump(ssadict, codecs.open(filename, 'w', encoding='utf-8'), separators=(',', ':'), sort_keys=True, indent=4)
+            json.dump(
+                ssadict, codecs.open(
+                    filename, 'w', encoding='utf-8'),
+                separators=(',', ':'), sort_keys=True, indent=4)
 
 
-    def __load_from_json(self,filename):
+    def __load_from_json(self, filename):
         if '.json' in filename:
 
             obj_text = codecs.open(filename, 'r', encoding='utf-8').read()
             ssadict = json.loads(obj_text)
 
             for key in ssadict.keys():
-                if key in ['solutions','all_trna_results','rib_means','time_vec_fixed','mean_autocorr','autocorr_vec','error_autocorr','rib_density','intensity_vec','I']:
+                if key in ['solutions', 'all_trna_results',
+                           'rib_means', 'time_vec_fixed',
+                           'mean_autocorr', 'autocorr_vec',
+                           'error_autocorr', 'rib_density',
+                           'intensity_vec', 'I']:
 
                     self.__dict__[key] = np.array(ssadict[key])
-                    
-                elif key in ['colpoints']: 
-                    
+
+                elif key in ['colpoints']:
+
                     cpts = [np.array(x) for x in ssadict[key]]
                     self.__dict__[key] = cpts
                 else:
