@@ -15,7 +15,7 @@ ODE_Soln = ODE_Soln.ODE_Soln
 
 
 import time
-
+import warnings
 import os
 
 ## Search locally for ssa_cpp
@@ -73,6 +73,20 @@ except:
     pass
 
 
+class Error(Exception):
+    """Base class for exceptions in this module."""
+    pass
+
+class CythonMissingError(Error):
+    """Exception raised for errors in the input.
+
+    Attributes:
+        message -- explanation of the error
+    """
+
+    def __init__(self, message):
+        self.message = message
+
 class TranslationSolvers():
     '''
     Container class for the solvers
@@ -258,7 +272,6 @@ class TranslationSolvers():
 
         for i in range(len(tags)):
             tag= tags[i]
-            print(tag)
             L = poi.total_length #get the total length of the gene
             Lm = np.mean(tag)  #the mean location of the tag epitopes
             L_after_tag = L - tag[-1]
@@ -291,6 +304,7 @@ class TranslationSolvers():
         return ui
 
 
+    '''
     def solve_ssa_set_conditions(self):
 
         ssa_conditions = self.default_conditions
@@ -357,7 +371,7 @@ class TranslationSolvers():
 
 
         return ssa_obj
-
+    '''
 
     def solve_ssa_trna(self,k_index, k_diffusion, k_bind, kelong,
                        k_compl, t,x0=[], k_trna = None,
@@ -410,11 +424,10 @@ class TranslationSolvers():
                 probe_vec = self.protein.probe_vec.astype(np.int32)
                 probe_loc = self.protein.probe_loc.astype(np.int32)
             else:
-                try:
-                    num = int("string")
-                except ValueError:
-                    print("no provided probe vector, please set the solver.protein with a protein object or provide a probe vector")
-
+                probe_loc = np.zeros([1,len(kelong)], dtype=np.int32)
+                probe_vec = np.zeros([1,len(kelong)], dtype=np.int32)
+                warnings.warn('no provided probe vector, using a blank probe'/
+                              '. This will result in zero sum intensity.')
         else:
             probe_vec = probe_vec
 
@@ -668,8 +681,11 @@ class TranslationSolvers():
                     probe_vec = self.protein.probe_vec.astype(np.int32)
                     probe_loc = self.protein.probe_loc.astype(np.int32)
             else:
-                print("no provided probe vector, please set the solver.protein with a protein object or provide a probe vector")
-                raise
+                probe_loc = np.zeros([1,len(ke)], dtype=np.int32)
+                probe_vec = np.zeros([1,len(ke)], dtype=np.int32)
+                warnings.warn('no provided probe vector, using a blank probe'/
+                              '. This will result in zero sum intensity.')
+                
         else:
             probe_vec = probe_vec
 
@@ -833,7 +849,7 @@ class TranslationSolvers():
 
 
 
-
+    '''
     def __solve_ssa(self,k,t,x0,n_traj,ssa_conditions=None):
 
         seeds = np.random.randint(0, 0x7FFFFFF, n_traj, dtype = np.int32)
@@ -984,7 +1000,7 @@ class TranslationSolvers():
 
         return ssa_obj
 
-
+    '''
 
 
     def __map_to_intensity(self):
@@ -993,7 +1009,7 @@ class TranslationSolvers():
 
 
     def __solve_ssa_trna(self, kindex, ktrna, kdiffusion, kbind, kelong,
-                         kcompl, t, x0, n_traj, ssa_conditions=None):
+                         kcompl, t, x0, n_traj, ssa_conditions=None, probe_vec=None ):
 
         seeds = np.random.randint(0, 0x7FFFFFF, n_traj, dtype=np.int32)
 
@@ -1007,7 +1023,13 @@ class TranslationSolvers():
         solutions = []
         solutionssave = []
         N_rib = 200
-        colors = self.colors
+        
+        if probe_vec == None:
+            pv = self.protein.probe_vec
+        else:
+            pv = probe_vec
+            
+        colors = int(pv.shape[0])
 
         n_trajectories = n_traj
 
@@ -1125,7 +1147,7 @@ class TranslationSolvers():
         startindex = np.where(t >= non_consider_time)[0][0]
 
         #all_results = all_results[:,startindex*N_rib:]
-        pv = self.protein.probe_vec
+        
         I = np.zeros((colors, len(t), n_traj))
 
         for n in range(colors):
@@ -1207,7 +1229,10 @@ class TranslationSolvers():
         st = time.time()
 
 
-        print('C++ library failed, Using Python Implementation')
+        warnings.warn('C++ extention missing or not compiled, using Python' \
+                      ' Implementation. This will be much slower!' \
+                      ' For C++ instillation instructions read the README or '\
+                          'visit the github page: https://github.com/MunskyGroup/rSNAPsim')
         rib_vec = []
 
         solutions = []
@@ -1400,8 +1425,7 @@ class TranslationSolvers():
         probe_vec = ssa_conditions['probe_vec']
 
         colors = int(probe_vec.shape[0])
-        print(probe_vec.shape)
-
+ 
 
         if ssa_conditions['bursting'] == False:
             kon = 1
@@ -1454,7 +1478,7 @@ class TranslationSolvers():
                 intime = float(intime)
                 seed = seeds[i]
                 colors = int(colors)
-            print(colors)
+           
             ssa_translation_lowmem.run_SSA(result, ribtimes, coltimes, colpointsx,colpointst, kelong,frapresult, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags, N_rib)
             #ssa_translation.run_SSA(result, ribtimes, coltimes, k[1:-1],frapresult, truetime, k[0], k[-1], evf, evi, intime, seeds[i],nribs)
 
@@ -1588,7 +1612,7 @@ class TranslationSolvers():
                           int(ssa_conditions['record_stats'])], dtype=np.int32)
         probe_loc = ssa_conditions['probe_loc']
 
-
+        colors = int(probe_loc.shape[0])
         rib_vec = []
         solutions = []
         solutionssave = []
@@ -1630,7 +1654,7 @@ class TranslationSolvers():
                 seed = seeds[i]
                 colors = int(colors)
 
-
+            
             ssa_translation_lowmem.run_SSA_full(ribloc, result, ribtimes, coltimes, colpointsx,colpointst, kelong,frapresult, t, ki, kt, evf, evi, intime, seed,nribs,x0,footprint, probe_vec ,colors, kon, koff, kprobe, probe_loc, flags)
             #ssa_translation.run_SSA(result, ribtimes, coltimes, k[1:-1],frapresult, truetime, k[0], k[-1], evf, evi, intime, seeds[i],nribs)
 
